@@ -6,6 +6,8 @@ from .deps import add_subcommand as add_deps_command
 from .stages import add_subcommand as add_stages_command
 from .targets import add_subcommand as add_targets_command
 from .python_path import add_subcommand as add_python_path_command
+from .test import add_subcommand as add_test_command
+from .md5_dir import add_subcommand as add_md5_command
 
 
 def get_parser() -> argparse.ArgumentParser:
@@ -19,7 +21,16 @@ def get_parser() -> argparse.ArgumentParser:
     add_stages_command(subparsers)
     add_targets_command(subparsers)
     add_python_path_command(subparsers)
+    add_test_command(subparsers)
+    add_md5_command(subparsers)
     return parser
 
 
+def exec():
+    parser = get_parser()
+
+    args = parser.parse_args()
+    args.exec(None, args)
+
+
 __all__ = ["get_parser"]
